( cd usr/lib ; rm -rf libalsatoss.so )
( cd usr/lib ; ln -sf libalsatoss.so.0.0.0 libalsatoss.so )
( cd usr/lib ; rm -rf libalsatoss.so.0 )
( cd usr/lib ; ln -sf libalsatoss.so.0.0.0 libalsatoss.so.0 )
( cd usr/lib ; rm -rf libaoss.so )
( cd usr/lib ; ln -sf libaoss.so.0.0.0 libaoss.so )
( cd usr/lib ; rm -rf libaoss.so.0 )
( cd usr/lib ; ln -sf libaoss.so.0.0.0 libaoss.so.0 )
